@@ -12,12 +12,12 @@ import numpy as np
 import pandas as pd
 from scipy.stats import chi2_contingency
 
-from evidently.utils.data_operations import DatasetColumns
-from evidently.utils.data_preprocessing import DataDefinition
-from evidently.utils.types import ColumnDistribution
-from evidently.utils.visualizations import Distribution
-from evidently.utils.visualizations import make_hist_for_cat_plot
-from evidently.utils.visualizations import make_hist_for_num_plot
+from mlopsdna.evidently.utils.data_operations import DatasetColumns
+from mlopsdna.evidently.utils.data_preprocessing import DataDefinition
+from mlopsdna.evidently.utils.types import ColumnDistribution
+from mlopsdna.evidently.utils.visualizations import Distribution
+from mlopsdna.evidently.utils.visualizations import make_hist_for_cat_plot
+from mlopsdna.evidently.utils.visualizations import make_hist_for_num_plot
 
 MAX_CATEGORIES = 5
 
