@@ -5,9 +5,9 @@ from typing import Optional
 
 import pandas as pd
 
-from evidently import ColumnMapping
-from evidently.dashboard.widgets.widget import Widget
-from evidently.model.widget import BaseWidgetInfo
+from mlopsdna.evidently import ColumnMapping
+from mlopsdna.evidently.dashboard.widgets.widget import Widget
+from mlopsdna.evidently.model.widget import BaseWidgetInfo
 
 
 class BarWidget(Widget):
