@@ -4,10 +4,10 @@ from typing import Optional
 
 import pandas as pd
 
-from evidently import ColumnMapping
-from evidently.dashboard.widgets.widget import Widget
-from evidently.model.widget import BaseWidgetInfo
-from evidently.utils.data_operations import process_columns
+from mlopsdna.evidently import ColumnMapping
+from mlopsdna.evidently.dashboard.widgets.widget import Widget
+from mlopsdna.evidently.model.widget import BaseWidgetInfo
+from mlopsdna.evidently.utils.data_operations import process_columns
 
 
 class ClassTargetNameWidget(Widget):
