@@ -1,6 +1,6 @@
-from evidently.features.generated_features import FeatureDescriptor
-from evidently.features.generated_features import GeneratedFeature
-from evidently.features.OOV_words_percentage_feature import OOVWordsPercentage
+from mlopsdna.evidently.features.generated_features import FeatureDescriptor
+from mlopsdna.evidently.features.generated_features import GeneratedFeature
+from mlopsdna.evidently.features.OOV_words_percentage_feature import OOVWordsPercentage
 
 
 class OOV(FeatureDescriptor):
