@@ -4,7 +4,7 @@ import platform
 
 import requests
 
-import mlopsdna.evidently
+import mlopsdna.evidently as evidently
 
 
 class TelemetrySender:
