@@ -5,28 +5,28 @@ from typing import List
 from typing import Optional
 from typing import Union
 
-from evidently.calculations.classification_performance import DatasetClassificationQuality
-from evidently.metrics.classification_performance.classification_dummy_metric import ClassificationDummyMetric
-from evidently.metrics.classification_performance.classification_quality_metric import ClassificationConfusionMatrix
-from evidently.metrics.classification_performance.classification_quality_metric import ClassificationQualityMetric
-from evidently.metrics.classification_performance.quality_by_class_metric import ClassificationQualityByClass
-from evidently.metrics.classification_performance.roc_curve_metric import ClassificationRocCurve
-from evidently.renderers.base_renderer import TestHtmlInfo
-from evidently.renderers.base_renderer import TestRenderer
-from evidently.renderers.base_renderer import default_renderer
-from evidently.renderers.html_widgets import TabData
-from evidently.renderers.html_widgets import get_roc_auc_tab_data
-from evidently.renderers.html_widgets import plotly_figure
-from evidently.renderers.html_widgets import widget_tabs
-from evidently.tests.base_test import BaseCheckValueTest
-from evidently.tests.base_test import GroupData
-from evidently.tests.base_test import GroupingTypes
-from evidently.tests.base_test import TestValueCondition
-from evidently.tests.utils import approx
-from evidently.tests.utils import plot_boxes
-from evidently.tests.utils import plot_conf_mtrx
-from evidently.tests.utils import plot_rates
-from evidently.utils.types import Numeric
+from mlopsdna.evidently.calculations.classification_performance import DatasetClassificationQuality
+from mlopsdna.evidently.metrics.classification_performance.classification_dummy_metric import ClassificationDummyMetric
+from mlopsdna.evidently.metrics.classification_performance.classification_quality_metric import ClassificationConfusionMatrix
+from mlopsdna.evidently.metrics.classification_performance.classification_quality_metric import ClassificationQualityMetric
+from mlopsdna.evidently.metrics.classification_performance.quality_by_class_metric import ClassificationQualityByClass
+from mlopsdna.evidently.metrics.classification_performance.roc_curve_metric import ClassificationRocCurve
+from mlopsdna.evidently.renderers.base_renderer import TestHtmlInfo
+from mlopsdna.evidently.renderers.base_renderer import TestRenderer
+from mlopsdna.evidently.renderers.base_renderer import default_renderer
+from mlopsdna.evidently.renderers.html_widgets import TabData
+from mlopsdna.evidently.renderers.html_widgets import get_roc_auc_tab_data
+from mlopsdna.evidently.renderers.html_widgets import plotly_figure
+from mlopsdna.evidently.renderers.html_widgets import widget_tabs
+from mlopsdna.evidently.tests.base_test import BaseCheckValueTest
+from mlopsdna.evidently.tests.base_test import GroupData
+from mlopsdna.evidently.tests.base_test import GroupingTypes
+from mlopsdna.evidently.tests.base_test import TestValueCondition
+from mlopsdna.evidently.tests.utils import approx
+from mlopsdna.evidently.tests.utils import plot_boxes
+from mlopsdna.evidently.tests.utils import plot_conf_mtrx
+from mlopsdna.evidently.tests.utils import plot_rates
+from mlopsdna.evidently.utils.types import Numeric
 
 CLASSIFICATION_GROUP = GroupData("classification", "Classification", "")
 GroupingTypes.TestGroup.add_value(CLASSIFICATION_GROUP)
