@@ -4,7 +4,7 @@ import json
 import numpy as np
 import pandas as pd
 
-from evidently.utils.types import ApproxValue
+from mlopsdna.evidently.utils.types import ApproxValue
 
 _TYPES_MAPPING = (
     (
