@@ -10,7 +10,7 @@ import pandas as pd
 from plotly import graph_objs as go
 from plotly.subplots import make_subplots
 
-from evidently.options.color_scheme import ColorOptions
+from mlopsdna.evidently.options.color_scheme import ColorOptions
 
 
 def plot_distr(*, hist_curr, hist_ref=None, orientation="v", color_options: ColorOptions) -> go.Figure:
