@@ -16,12 +16,12 @@ from sklearn.metrics import (
 )
 from sklearn.preprocessing import LabelBinarizer, label_binarize
 
-import bmomd.nannyml.sampling_error.binary_classification as bse
-import bmomd.nannyml.sampling_error.multiclass_classification as mse
-from bmomd.nannyml._typing import ModelOutputsType, ProblemType, class_labels
-from bmomd.nannyml.chunk import Chunk, Chunker
-from bmomd.nannyml.exceptions import CalculatorException, InvalidArgumentsException
-from bmomd.nannyml.sampling_error import SAMPLING_ERROR_RANGE
+import mlopsdna.nannyml.sampling_error.binary_classification as bse
+import mlopsdna.nannyml.sampling_error.multiclass_classification as mse
+from mlopsdna.nannyml._typing import ModelOutputsType, ProblemType, class_labels
+from mlopsdna.nannyml.chunk import Chunk, Chunker
+from mlopsdna.nannyml.exceptions import CalculatorException, InvalidArgumentsException
+from mlopsdna.nannyml.sampling_error import SAMPLING_ERROR_RANGE
 
 
 class Metric(abc.ABC):
