@@ -9,14 +9,14 @@ from pandas import MultiIndex
 from sklearn.impute import SimpleImputer
 from sklearn.preprocessing import OrdinalEncoder
 
-from bmomd.nannyml._typing import ProblemType, Self
-from bmomd.nannyml.base import AbstractEstimator, _list_missing, _split_features_by_type
-from bmomd.nannyml.chunk import Chunk, Chunker
-from bmomd.nannyml.exceptions import InvalidArgumentsException
-from bmomd.nannyml.performance_estimation.direct_loss_estimation import DEFAULT_METRICS
-from bmomd.nannyml.performance_estimation.direct_loss_estimation.metrics import Metric, MetricFactory
-from bmomd.nannyml.performance_estimation.direct_loss_estimation.result import Result
-from bmomd.nannyml.usage_logging import UsageEvent, log_usage
+from mlopsdna.nannyml._typing import ProblemType, Self
+from mlopsdna.nannyml.base import AbstractEstimator, _list_missing, _split_features_by_type
+from mlopsdna.nannyml.chunk import Chunk, Chunker
+from mlopsdna.nannyml.exceptions import InvalidArgumentsException
+from mlopsdna.nannyml.performance_estimation.direct_loss_estimation import DEFAULT_METRICS
+from mlopsdna.nannyml.performance_estimation.direct_loss_estimation.metrics import Metric, MetricFactory
+from mlopsdna.nannyml.performance_estimation.direct_loss_estimation.result import Result
+from mlopsdna.nannyml.usage_logging import UsageEvent, log_usage
 
 
 class DLE(AbstractEstimator):
